@@ -1,9 +1,9 @@
-use std::collections::{BTreeMap, HashMap};
+use std::collections::BTreeMap;
 use std::fmt::{Debug, Formatter};
 use std::fs;
 use std::hash::{Hash, Hasher};
 use std::path::{Path, PathBuf};
-use std::sync::{Arc, RwLock};
+use std::sync::Arc;
 
 use color_eyre::eyre::{eyre, Result, WrapErr};
 use console::style;
@@ -11,7 +11,8 @@ use itertools::Itertools;
 use rayon::prelude::*;
 use url::Url;
 
-use crate::backend::{ABackend, Backend, BackendList, BackendType};
+use crate::backend::external_plugin_cache::ExternalPluginCache;
+use crate::backend::{ABackend, Backend, BackendList};
 use crate::cache::CacheManager;
 use crate::cli::args::BackendArg;
 use crate::config::Config;
@@ -25,14 +26,13 @@ use crate::plugins::asdf_plugin::AsdfPlugin;
 use crate::plugins::mise_plugin_toml::MisePluginToml;
 use crate::plugins::Script::{Download, ExecEnv, Install, ParseLegacyFile};
 use crate::plugins::{Plugin, PluginType, Script, ScriptManager};
-use crate::tera::{get_tera, BASE_CONTEXT};
 use crate::toolset::{ToolRequest, ToolVersion, Toolset};
 use crate::ui::progress_report::SingleReport;
 use crate::{dirs, env, file, http};
 
 /// This represents a plugin installed to ~/.local/share/mise/plugins
-pub struct Asdf {
-    pub fa: BackendArg,
+pub struct AsdfBackend {
+    pub ba: BackendArg,
     pub name: String,
     pub plugin_path: PathBuf,
     pub repo_url: Option<String>,
@@ -45,34 +45,34 @@ pub struct Asdf {
     legacy_filename_cache: CacheManager<Vec<String>>,
 }
 
-impl Asdf {
-    pub fn new(name: String) -> Self {
+impl AsdfBackend {
+    pub fn from_arg(ba: BackendArg) -> Self {
+        let name = ba.short.to_string();
         let plugin_path = dirs::PLUGINS.join(&name);
         let mut toml_path = plugin_path.join("mise.plugin.toml");
         if plugin_path.join("rtx.plugin.toml").exists() {
             toml_path = plugin_path.join("rtx.plugin.toml");
         }
         let toml = MisePluginToml::from_file(&toml_path).unwrap();
-        let fa = BackendArg::new(BackendType::Asdf, &name);
         Self {
             cache: ExternalPluginCache::default(),
             remote_version_cache: CacheManager::new(
-                fa.cache_path.join("remote_versions-$KEY.msgpack.z"),
+                ba.cache_path.join("remote_versions-$KEY.msgpack.z"),
             )
             .with_fresh_duration(*env::MISE_FETCH_REMOTE_VERSIONS_CACHE)
             .with_fresh_file(plugin_path.clone())
             .with_fresh_file(plugin_path.join("bin/list-all")),
             latest_stable_cache: CacheManager::new(
-                fa.cache_path.join("latest_stable-$KEY.msgpack.z"),
+                ba.cache_path.join("latest_stable-$KEY.msgpack.z"),
             )
             .with_fresh_duration(*env::MISE_FETCH_REMOTE_VERSIONS_CACHE)
             .with_fresh_file(plugin_path.clone())
             .with_fresh_file(plugin_path.join("bin/latest-stable")),
-            alias_cache: CacheManager::new(fa.cache_path.join("aliases-$KEY.msgpack.z"))
+            alias_cache: CacheManager::new(ba.cache_path.join("aliases-$KEY.msgpack.z"))
                 .with_fresh_file(plugin_path.clone())
                 .with_fresh_file(plugin_path.join("bin/list-aliases")),
             legacy_filename_cache: CacheManager::new(
-                fa.cache_path.join("legacy_filenames-$KEY.msgpack.z"),
+                ba.cache_path.join("legacy_filenames-$KEY.msgpack.z"),
             )
             .with_fresh_file(plugin_path.clone())
             .with_fresh_file(plugin_path.join("bin/list-legacy-filenames")),
@@ -81,7 +81,7 @@ impl Asdf {
             repo_url: None,
             toml,
             name,
-            fa,
+            ba,
         }
     }
     pub fn plugin(&self) -> &dyn Plugin {
@@ -91,7 +91,8 @@ impl Asdf {
     pub fn list() -> Result<BackendList> {
         Ok(file::dir_subdirs(&dirs::PLUGINS)?
             .into_par_iter()
-            .map(|name| Arc::new(Self::new(name)) as ABackend)
+            .filter(|name| !dirs::PLUGINS.join(name).join("metadata.lua").exists())
+            .map(|name| Arc::new(Self::from_arg(name.into())) as ABackend)
             .collect())
     }
 
@@ -149,7 +150,7 @@ impl Asdf {
     }
 
     fn legacy_cache_file_path(&self, legacy_file: &Path) -> PathBuf {
-        self.fa
+        self.ba
             .cache_path
             .join("legacy")
             .join(&self.name)
@@ -264,23 +265,23 @@ impl Asdf {
     }
 }
 
-impl Eq for Asdf {}
+impl Eq for AsdfBackend {}
 
-impl PartialEq for Asdf {
+impl PartialEq for AsdfBackend {
     fn eq(&self, other: &Self) -> bool {
         self.name == other.name
     }
 }
 
-impl Hash for Asdf {
+impl Hash for AsdfBackend {
     fn hash<H: Hasher>(&self, state: &mut H) {
         self.name.hash(state);
     }
 }
 
-impl Backend for Asdf {
+impl Backend for AsdfBackend {
     fn fa(&self) -> &BackendArg {
-        &self.fa
+        &self.ba
     }
 
     fn get_plugin_type(&self) -> PluginType {
@@ -404,7 +405,7 @@ impl Backend for Asdf {
         }
         ctx.pr.set_message("installing".into());
         run_script(&Install)?;
-        file::remove_dir(&self.fa.downloads_path)?;
+        file::remove_dir(&self.ba.downloads_path)?;
 
         Ok(())
     }
@@ -445,113 +446,19 @@ impl Backend for Asdf {
     }
 }
 
-impl Debug for Asdf {
+impl Debug for AsdfBackend {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         f.debug_struct("ExternalPlugin")
             .field("name", &self.name)
             .field("plugin_path", &self.plugin_path)
-            .field("cache_path", &self.fa.cache_path)
-            .field("downloads_path", &self.fa.downloads_path)
-            .field("installs_path", &self.fa.installs_path)
+            .field("cache_path", &self.ba.cache_path)
+            .field("downloads_path", &self.ba.downloads_path)
+            .field("installs_path", &self.ba.installs_path)
             .field("repo_url", &self.repo_url)
             .finish()
     }
 }
 
-#[derive(Debug, Default)]
-pub struct ExternalPluginCache {
-    list_bin_paths: RwLock<HashMap<ToolRequest, CacheManager<Vec<String>>>>,
-    exec_env: RwLock<HashMap<ToolRequest, CacheManager<BTreeMap<String, String>>>>,
-}
-
-impl ExternalPluginCache {
-    pub fn list_bin_paths<F>(
-        &self,
-        plugin: &Asdf,
-        tv: &ToolVersion,
-        fetch: F,
-    ) -> eyre::Result<Vec<String>>
-    where
-        F: FnOnce() -> eyre::Result<Vec<String>>,
-    {
-        let mut w = self.list_bin_paths.write().unwrap();
-        let cm = w.entry(tv.request.clone()).or_insert_with(|| {
-            let list_bin_paths_filename = match &plugin.toml.list_bin_paths.cache_key {
-                Some(key) => {
-                    let config = Config::get();
-                    let key = render_cache_key(&config, tv, key);
-                    let filename = format!("{}-$KEY.msgpack.z", key);
-                    tv.cache_path().join("list_bin_paths").join(filename)
-                }
-                None => tv.cache_path().join("list_bin_paths-$KEY.msgpack.z"),
-            };
-            CacheManager::new(list_bin_paths_filename)
-                .with_fresh_file(dirs::DATA.to_path_buf())
-                .with_fresh_file(plugin.plugin_path.clone())
-                .with_fresh_file(tv.install_path())
-        });
-        cm.get_or_try_init(fetch).cloned()
-    }
-
-    pub fn exec_env<F>(
-        &self,
-        config: &Config,
-        plugin: &Asdf,
-        tv: &ToolVersion,
-        fetch: F,
-    ) -> eyre::Result<BTreeMap<String, String>>
-    where
-        F: FnOnce() -> eyre::Result<BTreeMap<String, String>>,
-    {
-        let mut w = self.exec_env.write().unwrap();
-        let cm = w.entry(tv.request.clone()).or_insert_with(|| {
-            let exec_env_filename = match &plugin.toml.exec_env.cache_key {
-                Some(key) => {
-                    let key = render_cache_key(config, tv, key);
-                    let filename = format!("{}-$KEY.msgpack.z", key);
-                    tv.cache_path().join("exec_env").join(filename)
-                }
-                None => tv.cache_path().join("exec_env-$KEY.msgpack.z"),
-            };
-            CacheManager::new(exec_env_filename)
-                .with_fresh_file(dirs::DATA.to_path_buf())
-                .with_fresh_file(plugin.plugin_path.clone())
-                .with_fresh_file(tv.install_path())
-        });
-        cm.get_or_try_init(fetch).cloned()
-    }
-}
-
-fn render_cache_key(config: &Config, tv: &ToolVersion, cache_key: &[String]) -> String {
-    let elements = cache_key
-        .iter()
-        .map(|tmpl| {
-            let s = parse_template(config, tv, tmpl).unwrap();
-            let s = s.trim().to_string();
-            trace!("cache key element: {} -> {}", tmpl.trim(), s);
-            let mut s = hash_to_str(&s);
-            s.truncate(10);
-            s
-        })
-        .collect::<Vec<String>>();
-    elements.join("-")
-}
-
-fn parse_template(config: &Config, tv: &ToolVersion, tmpl: &str) -> eyre::Result<String> {
-    let mut ctx = BASE_CONTEXT.clone();
-    ctx.insert("project_root", &config.project_root);
-    ctx.insert("opts", &tv.request.options());
-    get_tera(
-        config
-            .project_root
-            .as_ref()
-            .or(env::current_dir().as_ref().ok())
-            .map(|p| p.as_path()),
-    )
-    .render_str(tmpl, &ctx)
-    .wrap_err_with(|| eyre!("failed to parse template: {tmpl}"))
-}
-
 fn normalize_remote(remote: &str) -> eyre::Result<String> {
     let url = Url::parse(remote)?;
     let host = url.host_str().unwrap();
@@ -570,7 +477,7 @@ mod tests {
     #[test]
     fn test_debug() {
         reset();
-        let plugin = Asdf::new(String::from("dummy"));
+        let plugin = AsdfBackend::from_arg("dummy".into());
         assert!(format!("{:?}", plugin).starts_with("ExternalPlugin { name: \"dummy\""));
     }
 }
